Getting started
=====

.. _installation:

Installation
------------

To use JAX-in-Cell, there is no need to install it.
You can simply clone the repository and install the dependencies using the following command:

.. code-block:: console

    $ git clone https://github.com/uwplasma/JAX-in-Cell.git
    $ cd JAX-in-Cell
    $ pip install -r requirements.txt

these are

    - jax
    - jax_tqdm
    - matplotlib

Run an example
--------------

To run the main example, use the following command:

.. code-block:: console

    python main.py

More examples are in the `examples` folder.